import mysql.connector 
import webbrowser

connection = mysql.connector.connect(user='root', password='', host ='104.197.120.134', database='ftdwkey')
cursor = connection.cursor()

def get_access():
    return connection, cursor

def download_csv():
    url = 'https://storage.googleapis.com/ftdbucket/ftd/ftdcln.csv'
    return webbrowser.open(url)

def ftd_schema():
    return cursor.column_names

def most_recent_settlementdate():
    cursor = connection.cursor(buffered=True, dictionary=True)
    cursor.execute("SELECT settlementdate FROM ftdwkey ORDER BY settlementdate DESC LIMIT 1")
    settlementdate = cursor.fetchone()
    cursor = connection.cursor()
    return settlementdate['settlementdate']



from setuptools import setup

setup(name='ftdpack',
version='1.0',
description='package to access failure to deliver data',
url='https://github.com/jc22dora/ftdpack',
author='John Doran',
author_email='jdorrkng@jdoran.dev',
license='MIT',
packages=['ftd'],
install_requires=['mysql-connector==2.2.9'],
zip_safe=False)


